==> ca-sdk-2.0.1-20211108.054021-15-sources.jar: com/xdja/ca/bean/SignedAndEnvelopedData.java <==
package com.xdja.ca.bean;

import org.bouncycastle.asn1.*;
import org.bouncycastle.asn1.cms.EncryptedContentInfo;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.Enumeration;

public class SignedAndEnvelopedData implements ASN1Encodable
{
	private ASN1Integer version;
	private ASN1Set recipientInfos;
	private ASN1Set digestAlgorithms;
	private EncryptedContentInfo encryptedContentInfo;
	private ASN1Set certificates;
	private ASN1Set crls;
	private ASN1Set signerInfos;
	private boolean certsBer;
	private boolean crlsBer;

	public static SignedAndEnvelopedData getInstance(Object obj)
	{
		if (null == obj) {
			throw new IllegalArgumentException("unknown object in factory: ");
		}
		if ((obj instanceof SignedAndEnvelopedData)) {
			return (SignedAndEnvelopedData) obj;
		}
		if ((obj instanceof ASN1Sequence)) {
			return new SignedAndEnvelopedData((ASN1Sequence)obj);
		}

		throw new IllegalArgumentException("unknown object in factory: " +
				obj.getClass().getName());
	}

	public SignedAndEnvelopedData(ASN1Integer version, ASN1Set recipientInfos, ASN1Set digestAlgorithms, EncryptedContentInfo encryptedContentInfo, ASN1Set certificates, ASN1Set crls, ASN1Set signerInfos)
	{
		this.version = version;

		this.recipientInfos = recipientInfos;
		this.digestAlgorithms = digestAlgorithms;
		this.encryptedContentInfo = encryptedContentInfo;

		this.certificates = certificates;
		this.crls = crls;
		this.signerInfos = signerInfos;

		this.crlsBer = (crls instanceof BERSet);
		this.certsBer = (certificates instanceof BERSet);
	}

	public SignedAndEnvelopedData(ASN1Sequence seq)
	{
		Enumeration e = seq.getObjects();
		this.version = ((ASN1Integer)e.nextElement());

		if (this.version.getValue().intValue() != 1) {
			throw new IllegalArgumentException("SignedAndEnvelopedData not version 1");
		}

		this.recipientInfos = ((ASN1Set)e.nextElement());
		this.digestAlgorithms = ((ASN1Set)e.nextElement());
		this.encryptedContentInfo = EncryptedContentInfo.getInstance(e.nextElement());

		while (e.hasMoreElements()) {
		    ASN1Object o = (ASN1Object) e.nextElement();

			if ((o instanceof DERTaggedObject)) {
				DERTaggedObject tagged = (DERTaggedObject)o;
				switch (tagged.getTagNo()) {
					case 0:
						this.certificates = ASN1Set.getInstance(tagged, false);
						break;
					case 1:
						this.crls = ASN1Set.getInstance(tagged, false);
						break;
					default:
						throw new IllegalArgumentException("unknown tag value " +
								tagged.getTagNo());
				}
			}
			else {
				this.signerInfos = ((ASN1Set)o);
			}
		}
	}

	public ASN1Integer getVersion()
	{
		return this.version;
	}

	public ASN1Set getRecipientInfos()
	{
		return this.recipientInfos;
	}

	public ASN1Set getDigestAlgorithms()
	{
		return this.digestAlgorithms;
	}

	public EncryptedContentInfo getEncryptedContentInfo()
	{
		return this.encryptedContentInfo;
	}

	public ASN1Set getCertificates()
	{
		return this.certificates;
	}

	public ASN1Set getCrls()
	{
		return this.crls;
	}

	public ASN1Set getSignerInfos()
	{
		return this.signerInfos;
	}

/*	public DERObject toASN1Object()
	{
		ASN1EncodableVector v = new ASN1EncodableVector();

		v.add(this.version);
		v.add(this.recipientInfos);
		v.add(this.digestAlgorithms);
		v.add(this.encryptedContentInfo);

		if (this.certificates != null)
		{
			if (this.certsBer)
			{
				v.add(new BERTaggedObject(false, 0, this.certificates));
			}
			else
			{
				v.add(new DERTaggedObject(false, 0, this.certificates));
			}
		}

		if (this.crls != null)
		{
			if (this.crlsBer)
			{
				v.add(new BERTaggedObject(false, 1, this.crls));
			}
			else
			{
				v.add(new DERTaggedObject(false, 1, this.crls));
			}
		}

		v.add(this.signerInfos);

		return new BERSequence(v);
	}*/

    /**
     * Return an object, possibly constructed, of ASN.1 primitives
     *
     * @return an ASN.1 primitive.
     */
    @Override
    public ASN1Primitive toASN1Primitive() {
        ASN1EncodableVector  v = new ASN1EncodableVector();

        v.add(this.version);
        v.add(this.recipientInfos);
        v.add(this.digestAlgorithms);
        v.add(this.encryptedContentInfo);

        if (this.certificates != null)
        {
            if (this.certsBer)
            {
                v.add(new BERTaggedObject(false, 0, this.certificates));
            }
            else
            {
                v.add(new DERTaggedObject(false, 0, this.certificates));
            }
        }

        if (this.crls != null)
        {
            if (this.crlsBer)
            {
                v.add(new BERTaggedObject(false, 1, this.crls));
            }
            else
            {
                v.add(new DERTaggedObject(false, 1, this.crls));
            }
        }

        v.add(this.signerInfos);

        return new BERSequence(v);
    }

	public byte[] getDEREncoded() {
		try {
			ByteArrayOutputStream bOut = new ByteArrayOutputStream();
			DEROutputStream dOut = new DEROutputStream(bOut);
			dOut.writeObject(this);
			return bOut.toByteArray();
		} catch (IOException var2) {
			return null;
		}
	}
}

==> ca-sdk-2.0.1-20241226.054625-17-sources.jar: com/xdja/ca/bean/SignedAndEnvelopedData.java <==
package com.xdja.ca.bean;

import org.bouncycastle.asn1.*;
import org.bouncycastle.asn1.cms.EncryptedContentInfo;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.Enumeration;

public class SignedAndEnvelopedData implements ASN1Encodable
{
	private ASN1Integer version;
	private ASN1Set recipientInfos;
	private ASN1Set digestAlgorithms;
	private EncryptedContentInfo encryptedContentInfo;
	private ASN1Set certificates;
	private ASN1Set crls;
	private ASN1Set signerInfos;
	private boolean certsBer;
	private boolean crlsBer;

	public static SignedAndEnvelopedData getInstance(Object obj)
	{
		if (null == obj) {
			throw new IllegalArgumentException("unknown object in factory: ");
		}
		if ((obj instanceof SignedAndEnvelopedData)) {
			return (SignedAndEnvelopedData) obj;
		}
		if ((obj instanceof ASN1Sequence)) {
			return new SignedAndEnvelopedData((ASN1Sequence)obj);
		}

		throw new IllegalArgumentException("unknown object in factory: " +
				obj.getClass().getName());
	}

	public SignedAndEnvelopedData(ASN1Integer version, ASN1Set recipientInfos, ASN1Set digestAlgorithms, EncryptedContentInfo encryptedContentInfo, ASN1Set certificates, ASN1Set crls, ASN1Set signerInfos)
	{
		this.version = version;

		this.recipientInfos = recipientInfos;
		this.digestAlgorithms = digestAlgorithms;
		this.encryptedContentInfo = encryptedContentInfo;

		this.certificates = certificates;
		this.crls = crls;
		this.signerInfos = signerInfos;

		this.crlsBer = (crls instanceof BERSet);
		this.certsBer = (certificates instanceof BERSet);
	}

	public SignedAndEnvelopedData(ASN1Sequence seq)
	{
		Enumeration e = seq.getObjects();
		this.version = ((ASN1Integer)e.nextElement());

		if (this.version.getValue().intValue() != 1) {
			throw new IllegalArgumentException("SignedAndEnvelopedData not version 1");
		}

		this.recipientInfos = ((ASN1Set)e.nextElement());
		this.digestAlgorithms = ((ASN1Set)e.nextElement());
		this.encryptedContentInfo = EncryptedContentInfo.getInstance(e.nextElement());

		while (e.hasMoreElements()) {
		    ASN1Object o = (ASN1Object) e.nextElement();

			if ((o instanceof DERTaggedObject)) {
				DERTaggedObject tagged = (DERTaggedObject)o;
				switch (tagged.getTagNo()) {
					case 0:
						this.certificates = ASN1Set.getInstance(tagged, false);
						break;
					case 1:
						this.crls = ASN1Set.getInstance(tagged, false);
						break;
					default:
						throw new IllegalArgumentException("unknown tag value " +
								tagged.getTagNo());
				}
			}
			else {
				this.signerInfos = ((ASN1Set)o);
			}
		}
	}

	public ASN1Integer getVersion()
	{
		return this.version;
	}

	public ASN1Set getRecipientInfos()
	{
		return this.recipientInfos;
	}

	public ASN1Set getDigestAlgorithms()
	{
		return this.digestAlgorithms;
	}

	public EncryptedContentInfo getEncryptedContentInfo()
	{
		return this.encryptedContentInfo;
	}

	public ASN1Set getCertificates()
	{
		return this.certificates;
	}

	public ASN1Set getCrls()
	{
		return this.crls;
	}

	public ASN1Set getSignerInfos()
	{
		return this.signerInfos;
	}

/*	public DERObject toASN1Object()
	{
		ASN1EncodableVector v = new ASN1EncodableVector();

		v.add(this.version);
		v.add(this.recipientInfos);
		v.add(this.digestAlgorithms);
		v.add(this.encryptedContentInfo);

		if (this.certificates != null)
		{
			if (this.certsBer)
			{
				v.add(new BERTaggedObject(false, 0, this.certificates));
			}
			else
			{
				v.add(new DERTaggedObject(false, 0, this.certificates));
			}
		}

		if (this.crls != null)
		{
			if (this.crlsBer)
			{
				v.add(new BERTaggedObject(false, 1, this.crls));
			}
			else
			{
				v.add(new DERTaggedObject(false, 1, this.crls));
			}
		}

		v.add(this.signerInfos);

		return new BERSequence(v);
	}*/

    /**
     * Return an object, possibly constructed, of ASN.1 primitives
     *
     * @return an ASN.1 primitive.
     */
    @Override
    public ASN1Primitive toASN1Primitive() {
        ASN1EncodableVector  v = new ASN1EncodableVector();

        v.add(this.version);
        v.add(this.recipientInfos);
        v.add(this.digestAlgorithms);
        v.add(this.encryptedContentInfo);

        if (this.certificates != null)
        {
            if (this.certsBer)
            {
                v.add(new BERTaggedObject(false, 0, this.certificates));
            }
            else
            {
                v.add(new DERTaggedObject(false, 0, this.certificates));
            }
        }

        if (this.crls != null)
        {
            if (this.crlsBer)
            {
                v.add(new BERTaggedObject(false, 1, this.crls));
            }
            else
            {
                v.add(new DERTaggedObject(false, 1, this.crls));
            }
        }

        v.add(this.signerInfos);

        return new BERSequence(v);
    }

	public byte[] getDEREncoded() {
		try {
			ByteArrayOutputStream bOut = new ByteArrayOutputStream();
			//DEROutputStream dOut = new DEROutputStream(bOut);
//			ASN1OutputStream dOut = new ASN1OutputStream(bOut);
			// 修改依赖BC库从1.60版本升级1.69版本时，获取DER编码数据错误问题  Modify by wyf 2023-07-12 20:38
			ASN1OutputStream dOut = ASN1OutputStream.create(bOut, ASN1Encoding.DER); 
			dOut.writeObject(this);
			return bOut.toByteArray();
		} catch (IOException var2) {
			return null;
		}
	}
}
